NodeResponse

Enum NodeResponse 

pub enum NodeResponse<UserResponse: UserResponseTrait, NodeData: NodeDataTrait> {
    ConnectEventStarted(NodeId, AnyParameterId),
    ConnectEventEnded {
        output: OutputId,
        input: InputId,
    },
    CreatedNode(NodeId),
    SelectNode(NodeId),
    DeleteNodeUi(NodeId),
    DeleteNodeFull {
        node_id: NodeId,
        node: Node<NodeData>,
    },
    DisconnectEvent {
        output: OutputId,
        input: InputId,
    },
    RaiseNode(NodeId),
    MoveNode {
        node: NodeId,
        drag_delta: Vec2,
    },
    User(UserResponse),
}
Nodes communicate certain events to the parent graph when drawn. There is one special User variant which can be used by users as the return value when executing some custom actions in the UI of the node.

Variants



ConnectEventStarted(NodeId, AnyParameterId)



ConnectEventEnded

Fields

output: OutputId
input: InputId


CreatedNode(NodeId)



SelectNode(NodeId)



DeleteNodeUi(NodeId)

As a user of this library, prefer listening for DeleteNodeFull which will also contain the user data for the deleted node.



DeleteNodeFull

Emitted when a node is deleted. The node will no longer exist in the graph after this response is returned from the draw function, but its contents are passed along with the event.

Fields

node_id: NodeId
node: Node<NodeData>


DisconnectEvent

Fields

output: OutputId
input: InputId


RaiseNode(NodeId)

Emitted when a node is interacted with, and should be raised



MoveNode

Fields

node: NodeId
drag_delta: Vec2


User(UserResponse)