pub enum InputParamKind {
ConnectionOnly,
ConstantOnly,
ConnectionOrConstant,
}Expand description
The three kinds of input params. These describe how the graph must behave with respect to inline widgets and connections for this parameter.
Variants
ConnectionOnly
No constant value can be set. Only incoming connections can produce it
ConstantOnly
Only a constant value can be set. No incoming connections accepted.
ConnectionOrConstant
Both incoming connections and constants are accepted. Connections take precedence over the constant values.