pub struct InputId(/* private fields */);Trait Implementations
Sourceimpl From<InputId> for AnyParameterId
impl From<InputId> for AnyParameterId
Sourceimpl Key for InputId
impl Key for InputId
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for InputId
impl Ord for InputId
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for InputId
impl PartialOrd for InputId
impl Copy for InputId
impl Eq for InputId
impl StructuralPartialEq for InputId