pub struct OutputId(/* private fields */);Trait Implementations
Sourceimpl From<OutputId> for AnyParameterId
impl From<OutputId> for AnyParameterId
Sourceimpl Key for OutputId
impl Key for OutputId
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for OutputId
impl Ord for OutputId
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for OutputId
impl PartialOrd for OutputId
impl Copy for OutputId
impl Eq for OutputId
impl StructuralPartialEq for OutputId