pub trait NodeTemplateIter {
type Item;
// Required method
fn all_kinds(&self) -> Vec<Self::Item>;
}Expand description
This trait can be implemented by any user type. The trait tells the library how to enumerate the node templates it will present to the user as part of the node finder.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".